@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: VariableProvider.java,v 1.17 2001/11/07 22:37:07 metlov Exp $
+ * $Id: VariableProvider.java,v 1.18 2002/12/06 13:52:50 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -18,6 +18,7 @@ public class VariableProvider extends gnu.jel.DVMap {
   public Object anObject=new Object();
 
   public double xvar;
+  public String strVar;
   
   public double x() {return xvar;};
   public static double xS() {return 5.3;};
@@ -58,10 +59,20 @@ public class VariableProvider extends gnu.jel.DVMap {
     if (val.getClass()==DoubleObject.class) return "TSDouble";
     if (val instanceof gnu.jel.reflect.Double) return "Double";
     if (val instanceof gnu.jel.reflect.Boolean) return "Boolean";
-    
+
+    //-------- FOR JULIA DUNPHY
+    if (val instanceof double[]) return "DoubleArr";
+    //======== FOR JULIA DUNPHY
+
     return null;
   };
-  
+
+  //-------- FOR JULIA DUNPHY
+  public double[] getDoubleArrProperty(String name) {
+    return (double[]) properties.get(name);
+  };
+  //======== FOR JULIA DUNPHY
+
   // --- END OF (Dynamic variables testing section)
 
   public gnu.jel.reflect.Double[] arrDoubleJELObj1={
