@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: ClassFile.java,v 1.21 2002/02/13 02:14:44 metlov Exp $
+ * $Id: ClassFile.java,v 1.22 2003/09/23 16:19:24 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -117,19 +117,19 @@ public class ClassFile implements Cloneable {
     text=new byte[256];
 
     if (Debug.enabled)
-      Debug.assert(cstk.length==6);
+      Debug.check(cstk.length==6);
     for (int i=0;i<6;i++)
       cstk[i]=new IntegerStack();
 
     try {
       if (Debug.enabled) // check if the name is in historical form
-        Debug.assert(name.indexOf('.')==-1);
+        Debug.check(name.indexOf('.')==-1);
 
       getUTFIndex(name); // must be the first entry
             
 
       if (Debug.enabled)
-        Debug.assert((modifiers & ~(java.lang.reflect.Modifier.PUBLIC+
+        Debug.check((modifiers & ~(java.lang.reflect.Modifier.PUBLIC+
                                     java.lang.reflect.Modifier.FINAL+
                                     java.lang.reflect.Modifier.INTERFACE+
                                     java.lang.reflect.Modifier.ABSTRACT))==0);
@@ -141,7 +141,7 @@ public class ClassFile implements Cloneable {
       // CONSTANT_CLASS for a new class, has to be written by hand
       // since no corresponding java.lang.Class object exists yet.
       if (Debug.enabled)
-        Debug.assert(poolEntries==2);
+        Debug.check(poolEntries==2);
       
       poolEntries++;
       constPool.write(7);
@@ -160,7 +160,7 @@ public class ClassFile implements Cloneable {
       writeShort(nInterfaces);
       for(int i=0;i<nInterfaces;i++) {
         if (Debug.enabled)
-          Debug.assert(interfaces[i].isInterface());
+          Debug.check(interfaces[i].isInterface());
         writeShort(getIndex(interfaces[i],9));
       };
       
@@ -173,7 +173,7 @@ public class ClassFile implements Cloneable {
         LocalField cLF=fields[i];
         
         if (Debug.enabled)
-          Debug.assert(!(cLF instanceof LocalMethod));
+          Debug.check(!(cLF instanceof LocalMethod));
         
         writeShort(cLF.getModifiers());
         writeShort(getUTFIndex(cLF.getName()));
@@ -207,7 +207,7 @@ public class ClassFile implements Cloneable {
       res.branchStack=res.branchStack.copy();
 
       if (Debug.enabled)
-        Debug.assert(cstk.length==6);
+        Debug.check(cstk.length==6);
       res.cstk=new IntegerStack[6];
       for(int i=0;i<6;i++)
         res.cstk[i]=cstk[i].copy();
@@ -243,10 +243,10 @@ public class ClassFile implements Cloneable {
   public void newMethod(LocalMethod m, Class[] vars) {
 
     if (Debug.enabled) {
-      Debug.assert(cW==0);
+      Debug.check(cW==0);
       for(int i=0;i<6;i++)
-        Debug.assert(cstk[i].size()==0);
-      Debug.assert(currJump==0);
+        Debug.check(cstk[i].size()==0);
+      Debug.check(currJump==0);
     };
     
     // first finish the last method
@@ -299,7 +299,7 @@ public class ClassFile implements Cloneable {
       paramsVars=new int[nLocalVars];
       
       if (Debug.enabled)
-        Debug.assert(cW==0);
+        Debug.check(cW==0);
 
       for (int i=0;i<paramsVars.length;i++) {
         int j=i-this_num;
@@ -400,18 +400,18 @@ public class ClassFile implements Cloneable {
    */ 
   public void noteStk(int s,int a) {
     if (Debug.enabled)
-      Debug.assert(cW<=mW);
+      Debug.check(cW<=mW);
 
     // void type can't be pushed yet, later this might change
     if (Debug.enabled)
-      Debug.assert((s!=9) && (a!=9));
+      Debug.check((s!=9) && (a!=9));
     
     if (s>=0) {
       cW--;
       if ((s & (~2)) == 5) cW--; // Note additional word for J and D
       
       if (Debug.enabled)
-        Debug.assert(cW>=0);
+        Debug.check(cW>=0);
     };
 
     if (a>=0) {
@@ -428,7 +428,7 @@ public class ClassFile implements Cloneable {
 
   static {
     if (Debug.enabled)
-      Debug.assert(OP.specialTypes.length==29,
+      Debug.check(OP.specialTypes.length==29,
                    "You changed special types in TypesStack please update "+
                    "specialClasses array in ClassFile.");
 
@@ -468,7 +468,7 @@ public class ClassFile implements Cloneable {
             break;
           case 2: // field
             if (Debug.enabled)
-              Debug.assert(params.length==0);
+              Debug.check(params.length==0);
             specialMethods[i]=definingClass.getField(name);
             break;
           default:
@@ -554,7 +554,7 @@ public class ClassFile implements Cloneable {
     while (op!=0) {
       char opc=(char)(op & 0xFFL);
       if (Debug.enabled)
-        Debug.assert(opc !=0xFF);
+        Debug.check(opc !=0xFF);
       
       final int mc=228;
       switch (opc-mc) {
@@ -573,7 +573,7 @@ public class ClassFile implements Cloneable {
         
         if (Debug.enabled) {
           branchStack.push(cW);
-          Debug.assert(cW>=beforeStk);
+          Debug.check(cW>=beforeStk);
         };
     
         // remove the result of the previous branch, the other branch must
@@ -590,7 +590,7 @@ public class ClassFile implements Cloneable {
         if (Debug.enabled) {
           code(0xFA); 
           // FA -- ensure_value();
-          Debug.assert((branchStack.pop()==cW),
+          Debug.check((branchStack.pop()==cW),
                        "Stack mismatch when compiling conditional");
           code(0xEFE9);
           // E9 -- unblock unconditional jumps
@@ -652,7 +652,7 @@ public class ClassFile implements Cloneable {
           
           if (iNJ ^ (s==0)) {
             if (Debug.enabled)
-              Debug.assert((currJump>=153) && (currJump<=166),
+              Debug.check((currJump>=153) && (currJump<=166),
                            "Attempt to invert non jump bytecode ("+
                            currJump+")");
             currJump=(((currJump-1) ^ 0x0001)+1);
@@ -725,7 +725,7 @@ public class ClassFile implements Cloneable {
         break;
       default:
         if (Debug.enabled)
-          Debug.assert(opc !=0xFF);
+          Debug.check(opc !=0xFF);
         write(opc);  
       };
       op=op >>> 8;
@@ -749,7 +749,7 @@ public class ClassFile implements Cloneable {
    */
   public final void codeLDC(Object o, int primitiveID) {
     if (Debug.enabled)  
-      Debug.assert(((primitiveID>=0) && (primitiveID<8)) || 
+      Debug.check(((primitiveID>=0) && (primitiveID<8)) || 
                    ((primitiveID==8) && (o==null)) || 
                    ((primitiveID==10) && (o instanceof StringBuffer)) ||
                    ((primitiveID==11) && (o instanceof String)));
@@ -801,7 +801,7 @@ public class ClassFile implements Cloneable {
       break;
     default:
       if (Debug.enabled) 
-        Debug.assert(false,"Loading of object constants is not supported by "+
+        Debug.check(false,"Loading of object constants is not supported by "+
                      "the Java class files.");
     };
     
@@ -824,7 +824,7 @@ public class ClassFile implements Cloneable {
       };
       
       if (Debug.enabled)  
-        Debug.assert((cpindex>=0) && (cpindex<=65535));
+        Debug.check((cpindex>=0) && (cpindex<=65535));
 
       
       if ((!dword_const) && (cpindex<=255)) {
@@ -992,7 +992,7 @@ public class ClassFile implements Cloneable {
   private int writeMemberRef(Member member, int entry) 
     throws java.io.IOException {
     if (Debug.enabled)
-      Debug.assert((entry==10)||(entry==9)||(entry==11));
+      Debug.check((entry==10)||(entry==9)||(entry==11));
     //  CONSTANT_Fieldref = 9;  CONSTANT_Methodref = 10; 
     //  CONSTANT_InterfaceMethodref = 11;
     
@@ -1784,7 +1784,7 @@ public class ClassFile implements Cloneable {
         };
         res.append(')');
         return res.toString();
-      };
+      }
     };
     if (o instanceof OPcondtnl) {
       OPcondtnl op=(OPcondtnl)o;
