@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: Library.java,v 1.19 2002/02/12 19:44:11 metlov Exp $
+ * $Id: Library.java,v 1.21 2003/10/15 14:08:12 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -142,13 +142,13 @@ public class Library {
    * <P>The array (dotClasses), which is the third argument of 
    * this constructor determines how (and whether) to compile the 
    * dot operators encountered in expressions. These operators are
-   * of the form <object>.(<method>|<field>), 
+   * of the form &lt;object&gt;.(&lt;method&gt;|&lt;field&gt;), 
    * which means to call method (access field)
-   * of an <object>. There can be three types of the behaviour: 
+   * of an &lt;object&gt;. There can be three types of the behaviour: 
    * <P>1) dot operators are prohibited (<TT>dotClasses==null</TT>),
    * this is behaviour of older version of JEL.
    * <P>2) dot operators are allowed on all classes
-   * (<TT>dotClasses==new Class[0], an empty array).
+   * (<tt>dotClasses==new Class[0]</tt>, an empty array).
    * Depending on the types of objects returned by the static/dynamic library
    * classes this may pose a security risk.
    * <P>3) dot operators are allowed only on some classes. This is achieved 
@@ -253,10 +253,11 @@ public class Library {
 
   /**
    * This method marks a static member as having the internal state.
-   * <P> If You include <TT>java.lang.Math</TT> into the library it is
-   * necessary to mark <TT>java.lang.random()</TT> as having the state. This
-   * can be done by calling <TT>markStateDependent("random",null)</TT>
-   * <P> Please specify parameters as close as possible, otherwise You can
+   * <P> If <TT>java.lang.Math</TT> is included into the library it is
+   * necessary to mark <TT>java.lang.Math.random()</TT> as having the
+   * state. This can be done by calling
+   * <TT>markStateDependent("random",null)</TT>.
+   * <P> Please specify parameters as close as possible, otherwise you can
    * accidentally mark another function.
    * @param name is the function name.
    * @param params are the possible invocation parameters of the function.
@@ -267,7 +268,7 @@ public class Library {
     Object m=getMember(null,name,params);
     Object removed=stateless.remove(m);
     if (Debug.enabled)
-      Debug.assert(removed!=null,"State dependent methos \""+m+
+      Debug.check(removed!=null,"State dependent methos \""+m+
 		   "\"is made state dependend again.");
   };
   
@@ -287,16 +288,16 @@ public class Library {
    * types is returned. If there are several methods the most specific one
    * is used. 
    * <P>Ambiguities are detected. Example of detectable ambiguity:<BR>
-   * You want to call : <TT>someName(int, int)<TT> <BR>
-   * There are two applicable methods : <TT>someName(int, double)<TT>,
-   * <TT>someName(double, int)<TT> , requirements to parameter types of each
-   *  of those can be satisfied by _widening_ conversions.<BR>
-   * Those methods are same specific, there is no most specific method in 
-   * terms of Java Language Specification (15.11.2.2). Thus there is ambiguity
+   * you ask for a call <TT>someName(int, int)</TT>, but there are two
+   * applicable methods <TT>someName(int, double)</TT> and
+   * <TT>someName(double, int)</TT>. Requirements to parameter types
+   * of both can be satisfied by _widening_ conversions. Thus, there
+   * is no most specific method of these two in terms of Java Language
+   * Specification (15.11.2.2). It means, that an ambiguity is present,
    * and null will be returned.
    * <P> Java compiler normally would not allow to define such ambiguous 
    * methods in the same class. However, as this library is assembled from
-   * several Java classes such ambiguities can happen, and should be
+   * several Java classes, such ambiguities can happen, and should be
    * detected.
    * @param container the class to search the method within, if <TT>null</TT>
    *                  the root namespace is searched.
@@ -419,7 +420,7 @@ public class Library {
   };
   
   /**
-   * Returns ID(position in the object array) of the dynamic Method.
+   * Returns ID (position in the object array) of the dynamic method.
    * <P> ID's are used to locate the pointers to the objects, implementing
    * dynamic methods, in the array, argument of evaluate(Object[]) function.
    * @param m method to get an ID of.
@@ -435,7 +436,7 @@ public class Library {
 
     /**
    * Used to get return type of a class member.
-   * <P>The type of a Method is its return type, the type of a Constructor is
+   * <P>The type of a method is its return type, the type of a constructor is
    * void.
    * @param  m member whose type is to be determined
    * @return type of the member
@@ -446,7 +447,7 @@ public class Library {
     if (m instanceof LocalField) return ((LocalField)m).getType();
     // otherwise it must be java.lang.reflect.Constructor
     if (Debug.enabled)
-      Debug.assert(m instanceof java.lang.reflect.Constructor);
+      Debug.check(m instanceof java.lang.reflect.Constructor);
     return OP.specialTypes[9]; // java.lang.reflect.Void.TYPE
   };
 
@@ -463,7 +464,7 @@ public class Library {
     if (m instanceof Constructor) return ((Constructor)m).getParameterTypes();
 
     if (Debug.enabled)
-      Debug.assert((m instanceof Field)||(m instanceof LocalField));
+      Debug.check((m instanceof Field)||(m instanceof LocalField));
     
     return new Class[0];
   };
