@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPbinary.java,v 1.19 2002/02/13 02:14:44 metlov Exp $
+ * $Id: OPbinary.java,v 1.20 2003/09/23 16:19:24 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -78,7 +78,7 @@ public class OPbinary extends OP {
    */
   public OPbinary(Stack paramOPs, int opcode) throws CompilationException {
     if (Debug.enabled)
-      Debug.assert((opcode>=0) && (opcode<opNames.length));
+      Debug.check((opcode>=0) && (opcode<opNames.length));
 
     // get the operands types
     chi=new OP[2];
@@ -231,11 +231,11 @@ public class OPbinary extends OP {
         // the only way the objects appear in this context
         // are the comparisons
         if (Debug.enabled) {
-          Debug.assert((code>=8)||(code<=13),
+          Debug.check((code>=8)||(code<=13),
                        "only comparisons and concatenation binops can "+
                        "operate on objects.");
-          Debug.assert(c1ID!=10, "No TSB in this context 1");
-          Debug.assert(c1ID!=10, "No TSB in this context 2");
+          Debug.check(c1ID!=10, "No TSB in this context 1");
+          Debug.check(c1ID!=10, "No TSB in this context 2");
         };
 
         // only string literal comparisons are interpreted
@@ -310,7 +310,7 @@ public class OPbinary extends OP {
             else 
               l1=l1>>>l2; 
             break; 
-          }; // RUS
+          } // RUS
           default :
             if (Debug.enabled)
               Debug.println("Wrong operation on integer ("+code+").");      
@@ -337,7 +337,7 @@ public class OPbinary extends OP {
       throw thr;
       //      Debug.reportThrowable(thr);
       // IGNORE
-    };
+    }
   };
 
 };
