@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPunary.java,v 1.19 2002/02/13 02:14:44 metlov Exp $
+ * $Id: OPunary.java,v 1.20 2003/09/23 16:19:24 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -60,7 +60,7 @@ public class OPunary extends OP {
     opNames=(String[])TableKeeper.getTable("opNames");
 
     if (Debug.enabled)
-      Debug.assert((opNames.length==una.length));
+      Debug.check((opNames.length==una.length));
   };
 
   /**
@@ -78,7 +78,7 @@ public class OPunary extends OP {
   public OPunary(Stack paramOPs, int code) 
     throws CompilationException {
     if (Debug.enabled)
-      Debug.assert((code>=0) && (code<=3));
+      Debug.check((code>=0) && (code<=3));
 
     this.code=code;
     chi=new OP[1];
@@ -124,13 +124,13 @@ public class OPunary extends OP {
                  boolean allownarrowing) throws CompilationException {
     if (Debug.enabled) {
       // check for proper target type was identification
-      Debug.assert(((targetID==8)^(targetClass==null)) ||
+      Debug.check(((targetID==8)^(targetClass==null)) ||
                    ((targetID!=8)&&
             (specialTypes[targetID].isAssignableFrom(targetClass)))
                    );
       
       if (targetID==8) {
-        Debug.assert(typeID(targetClass)==targetID,
+        Debug.check(typeID(targetClass)==targetID,
                      "The type was improperly identified for OPunary conv.");
       };
     };
@@ -262,7 +262,7 @@ public class OPunary extends OP {
         break;
       default:
         if (Debug.enabled)
-          Debug.assert(code>=0,"Wrong unary opcode.");
+          Debug.check(code>=0,"Wrong unary opcode.");
       };
       operand=narrow(val,resID);
     } else {
