@@ -1,6 +1,6 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
 /*
- * $Id: Parser.java,v 1.2 2002/02/13 02:14:44 metlov Exp $
+ * $Id: Parser.java,v 1.3 2003/09/23 16:19:24 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -233,14 +233,14 @@ public class Parser {
           read(); type=17; return;
         default:
           type=5; return;
-        };
+        }
       case '|':
         switch (read()) {
         case '|':
           read(); type=18; return;
         default:
           type=6; return;
-        };
+        }
       case '^':
         read(); type=7; return;
       case '=':
@@ -251,7 +251,7 @@ public class Parser {
           read(); type=9; return;
         default:
           type=31; return;
-        };
+        }
       case '<':
         switch (read()) {
         case '=':
@@ -260,7 +260,7 @@ public class Parser {
           read(); type=14; return;
         default:
           type=10; return;
-        };
+        }
       case '>':
         switch (read()) {
         case '=':
@@ -271,10 +271,10 @@ public class Parser {
             read(); type=16; return;
           default:
             type=15; return;
-          };
+          }
         default:
           type=12; return;
-        };
+        }
       case '~':
         read(); type = 30; return;
       case '[':
@@ -317,8 +317,8 @@ public class Parser {
           parseID();
           return;
         } else consume(-1);
-      };
-    };
+      }
+    }
   };
 
   // current char must be starting slash
@@ -356,8 +356,8 @@ public class Parser {
         // invalid escape character
         consume(-1);
         return -1; // never reached
-      };
-    };
+      }
+    }
   };
 
   private void parseChar() throws CompilationException {
@@ -386,7 +386,7 @@ public class Parser {
 
   private void parseString() throws CompilationException {
     if (Debug.enabled)
-      Debug.assert(buf.length()==0);
+      Debug.check(buf.length()==0);
 
     while(true) {
       switch(c) {
@@ -410,12 +410,12 @@ public class Parser {
         buf.append((char)c);
         read();
       };
-    };
+    }
   };
 
   private void parseID() throws CompilationException {
     if (Debug.enabled)
-      Debug.assert(buf.length()==0);
+      Debug.check(buf.length()==0);
     
     do {
       buf.append((char)c);
@@ -442,7 +442,7 @@ public class Parser {
   // is encountered
   private void parseNumber() throws CompilationException {
     if (Debug.enabled)
-      Debug.assert(buf.length()==0);
+      Debug.check(buf.length()==0);
     
     boolean seenDigit=false;
     boolean seen89=false;
@@ -702,7 +702,7 @@ public class Parser {
           result= (!arrCast) && (((c>='0') && (c<='9')) || 
                                  Character.isJavaIdentifierStart((char)c));
           break outerLoop;
-        };
+        }
 
     }; // outerLoop
 
@@ -743,7 +743,7 @@ public class Parser {
       // examine if it has set error position
       if (exc.col<0) {
         if (Debug.enabled)
-          Debug.assert(err_col>0);
+          Debug.check(err_col>0);
         exc.col=err_col; // set if not
         //exc.line=err_line; // not yet
       };
@@ -752,7 +752,7 @@ public class Parser {
     };
    
     if (Debug.enabled)
-      Debug.assert(paramOPs.size()==1,
+      Debug.check(paramOPs.size()==1,
                    "There must be only a single item left in paramOPs stack.");
     
     return (OP)paramOPs.pop();
@@ -788,7 +788,7 @@ public class Parser {
       err_col=ecol; // report errors against '?'
       
       if (Debug.enabled)
-        Debug.assert((paramOPs.size()==stackSizeAfterFirstBranch+1) &&
+        Debug.check((paramOPs.size()==stackSizeAfterFirstBranch+1) &&
                      (stackSizeAfterFirstBranch==stackSizeBeforeBranch+1),
                      "Stack in conditional branches is not balanced.");
       paramOPs.push(new OPcondtnl(paramOPs));
@@ -817,7 +817,7 @@ public class Parser {
 
     int t;
     if (Debug.enabled)
-      Debug.assert((idx>=0)&&(idx<=9));
+      Debug.check((idx>=0)&&(idx<=9));
     
     int v=(int)(idx<5?(0xA539CC68C652L>>>(idx*10)):
                 (0x820820E6A928L>>>((idx-5)*10)));
@@ -890,7 +890,7 @@ public class Parser {
         typeID++;
       
       if (Debug.enabled)
-        Debug.assert(typeID<=8);
+        Debug.check(typeID<=8);
    
       // this handles non-primitive types.
       if ((typeID==8) &&
