@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: TestSuite.java,v 1.42 2002/02/12 19:44:11 metlov Exp $
+ * $Id: TestSuite.java,v 1.45 2003/10/15 11:17:57 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -314,6 +314,7 @@ public class TestSuite {
     staticLib[1]=vp.getClass();  
     
     vp.xvar=5.0;
+    vp.strVar="strVar";
     rtp[0]=vp;
     dynamicLib[0]=vp.getClass();
     lib=new Library(staticLib,dynamicLib,null,null,null);
@@ -350,6 +351,8 @@ public class TestSuite {
 
     testExpression("arrDoubleJELObj1[0]+arrDoubleJELObj1[1]",
                    new Double(3.0), null, rtp, lib,o);
+    
+    testExpression("arrDoubleJELObj", vp.arrDoubleJELObj, null, rtp, lib,o);
 
     o.println(); o.println("----- TESTING COMPILED-in EXCEPTIONS (x=5)------");
     o.println();
@@ -375,10 +378,12 @@ public class TestSuite {
 
     testExpression("(\"abc\").length()", new Integer(3), null, rtp, lib,o);
     testExpression("\"abc\".length()", new Integer(3), null, rtp, lib,o);
+    testExpression("strVar.length()", new Integer(6), null, rtp, lib,o);
     testExpression("\"abc\".endsWith(\"bc\")", Boolean.TRUE, null, rtp, lib,o);
     testExpression("\"abc\".compareTo(\"bc\")", new Integer(-1), null, rtp, lib,o);
     testExpression("\"abcdbc\".indexOf(\"bc\")", new Integer(1), null, rtp, lib,o);
     testExpression("\"abcdbc\".indexOf(\"abc\".substring(1),2)", new Integer(4), null, rtp, lib,o);
+    
 
     testError("\"abc\".nomethod()",null,lib,7,o);
     testError("\"abc\".length(666)",null,lib,7,o);
@@ -492,6 +497,12 @@ public class TestSuite {
     testExpression("_T_j", "_U_j",null, rtp, lib,o);
     testExpression("_T_j+_T_g", "_U_j_U_g",null, rtp, lib,o);
 
+    //-------- FOR JULIA DUNPHY
+    double[] atemp={1.0,2.0};
+    vp.addProperty("A",atemp);
+    testExpression("A[0]+3.0", new Double(4.0), null, rtp, lib,o);    
+    //======== FOR JULIA DUNPHY
+
     o.println(); o.println("----- Automatic widening conversions of "+
                            "references ------");
 
@@ -1009,9 +1020,12 @@ public class TestSuite {
       for (int k=message.length();k<59;k++) o.print(' ');
 
       Object result=null;
+      Class compile_type=null;
       try {
         CompiledExpression expr_c=OpenEvaluator.compile(op);
-	
+
+        compile_type=expr_c.getTypeC();
+
         // Execute several times to enable JIT compilation.
         // Some JITs compile methods if they are run more than once
         for(int acounter=0;acounter<20;acounter++) {
@@ -1030,8 +1044,20 @@ public class TestSuite {
       
       if (tobe!=null) {
         if (result!=null) {
-          o.print(" ="); o.println(result);
+          o.print(" ="); o.print(result);
           testok=testok && (result.equals(tobe));
+          if (testok) {
+            if (!compile_type.isInstance(result)) {
+              o.println("");
+              o.println("WRONG COMPILE-TYPE !!!");
+              testok=false;
+            } else {
+              if (! result.getClass().equals(compile_type))
+                o.print("[!ETM got=\""+result.getClass()+"\" expected=\""+
+                        compile_type+"\"]");
+            };
+          };
+          o.println("");
         } else {
           o.println("NO RESULT");
           testok=false;
@@ -1127,7 +1153,7 @@ public class TestSuite {
         };
         res.append(')');
         return res.toString();
-      };
+      }
     };
     if (o instanceof OPcondtnl) {
       OPcondtnl op=(OPcondtnl)o;
@@ -1173,7 +1199,7 @@ class OpenEvaluator extends Evaluator {
 	} catch (Exception exc) {
       exc.printStackTrace();
       return null;
-	};
+	}
   };
   
 };
